import java.io.*;
import java.util.*;
import fiji.io.*;


/**
 * Classe che contiene il main
 * @author Barbara Pettazzoni
 * @version 1
 */
public class Concessionaria
{
	/**
	 * Main function
	 */
	public static void main(String args[])
	{
		//Leggiamo il file con le macchine, e 
		//memorizziamo le auto in un'apposita 
		//struttura ordinata.
		try
		{
			List<Auto> listaAuto = new Vector<Auto>();
			Lettore leggiFile = new Lettore(new FileReader("auto.txt"));
			while(!leggiFile.eof())
			{
				String linea = leggiFile.leggiLinea();
				//Ogni riga  un auto: nome prezzo km colore.
				StringTokenizer tokenizer = new StringTokenizer(linea," ");
				String nome = tokenizer.nextToken();
				int prezzo = Integer.valueOf(tokenizer.nextToken());
				int km = Integer.valueOf(tokenizer.nextToken());
				String colore = tokenizer.nextToken();
				listaAuto.add(new Auto(nome,prezzo,km,colore));
			}
			
			//Ordino le auto!
			Collections.sort(listaAuto);
			
			//A questo punto, possiamo preparare l'interfaccia
			Lettore lettore = new Lettore();
			boolean fine = false;
			System.out.println("Benvenuti presso la Vend O'Tutt!");
			while(!fine)
			{
				//Finche' l'utente non richiede l'apposita opzione, ripropongo l'interfaccia...
				stampaInterfaccia();
				String richiesta = lettore.leggiLinea();
				try
				{
					int richiestaNum = Integer.parseInt(richiesta);
					Iterator iterator;
					List<Auto> ricerca;
					switch(richiestaNum)
					{
						case 1: stampaAuto(listaAuto);
									 break;
						case 2: System.out.print("Inserisci il prezzo massimo: ");
									 try
									 {
									 	int prezzoMassimo = Integer.parseInt(lettore.leggiLinea());
									 	ricerca = new Vector<Auto>();
									 	for(Auto auto : listaAuto)
									 	{
									 		if(auto.getPrezzo() <= prezzoMassimo)
									 			ricerca.add(auto);
									 	}
									 	stampaAuto(ricerca);
									 }
									 catch(Exception e)
									 {
									 	System.out.println("Valore errato di prezzo");
									 }
									 break;
						case 3: System.out.print("Inserisci il chilometraggio massimo: ");
									 try
									 {
									 	int kmMassimi = Integer.parseInt(lettore.leggiLinea());
									 	ricerca = new Vector<Auto>();
									 	for(Auto auto: listaAuto)
									 	{
									 		if(auto.getChilometraggio() <= kmMassimi)
									 			ricerca.add(auto);
									 	}
									 	stampaAuto(ricerca);
									 }
									 catch(Exception e)
									 {
									 	System.out.println("Valore errato di chilometraggio massimo");
									 }
									 break;
						case 4: System.out.print("Inserisci il colore richiesto: ");
									 String colore = lettore.leggiLinea();
								 	 ricerca = new Vector<Auto>();
								 	 for(Auto auto: listaAuto)
								 	 {
								 	 	if(auto.getColore().equals(colore))
								  			ricerca.add(auto);
								     }
								 	 stampaAuto(ricerca);
									 break;
						case 5: System.out.print("Inserisci il tipo richiesto: ");
									 String nome = lettore.leggiLinea();
								 	 ricerca = new Vector<Auto>();
									 for(Auto auto : listaAuto)
								 	 {
								 	 	if(auto.getNome().equals(nome))
								  			ricerca.add(auto);
								     }
								 	 stampaAuto(ricerca);
									 break;
						case 6: fine = true;
									 break;
						default: System.out.println("Errore, scelta non esistente");
									 break;
					}
				}
				catch(Exception e)
				{
					System.out.println("Opzione errata");
				}
			}
			System.out.println("Grazie per averci consultato!");
		}
		catch(FileNotFoundException fnfe)
		{
			System.out.println("Non ho trovato il file!");
		}
	}
	
	private static void stampaInterfaccia()
	{
		System.out.println("Per favore, indica la scelta desiderata fra le seguenti: ");
		System.out.println("1) Stampa tutte le auto");
		System.out.println("2) Auto inferiori a un certo prezzo");
		System.out.println("3) Auto inferiori a un certo chilometraggio");
		System.out.println("4) Auto con un certo colore");
		System.out.println("5) Auto di un certo tipo");
		System.out.println("6) Esci");
		System.out.print("Indica la tua scelta (inserisci il numero): ");
	}
	
	
	//Da osservare che non  necessario ordinare anche queste liste! Sono gi ordinate!
	private static void stampaAuto(List<Auto> l)
	{
		System.out.println("------------");
		if(l.size() > 0)
		{
			for(Auto auto : l)
			{
				System.out.println(auto);
			}
		}
		else
			System.out.println("Non esistono auto con il criterio indicato");
		System.out.println("------------");
	}
}